All of lore.kernel.org
 help / color / mirror / Atom feed
From: "Yordan Karadzhov (VMware)" <y.karadz@gmail.com>
To: rostedt@goodmis.org
Cc: linux-trace-devel@vger.kernel.org,
	"Yordan Karadzhov (VMware)" <y.karadz@gmail.com>
Subject: [PATCH 3/4] libtracefs: Fix typo in function name
Date: Tue,  8 Jun 2021 16:55:02 +0300	[thread overview]
Message-ID: <20210608135503.12135-3-y.karadz@gmail.com> (raw)
In-Reply-To: <20210608135503.12135-1-y.karadz@gmail.com>

Fixes: 5c013e7 (libtracefs: New APIs for trace options)
Signed-off-by: Yordan Karadzhov (VMware) <y.karadz@gmail.com>
---
 include/tracefs.h   | 2 +-
 src/tracefs-tools.c | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/include/tracefs.h b/include/tracefs.h
index 08dda13..e29b550 100644
--- a/include/tracefs.h
+++ b/include/tracefs.h
@@ -159,7 +159,7 @@ bool tracefs_option_is_supported(struct tracefs_instance *instance, enum tracefs
 const struct tracefs_options_mask *tracefs_options_get_enabled(struct tracefs_instance *instance);
 bool tracefs_option_is_enabled(struct tracefs_instance *instance, enum tracefs_option_id id);
 int tracefs_option_enable(struct tracefs_instance *instance, enum tracefs_option_id id);
-int tracefs_option_diasble(struct tracefs_instance *instance, enum tracefs_option_id id);
+int tracefs_option_disable(struct tracefs_instance *instance, enum tracefs_option_id id);
 const char *tracefs_option_name(enum tracefs_option_id id);
 enum tracefs_option_id tracefs_option_id(const char *name);
 
diff --git a/src/tracefs-tools.c b/src/tracefs-tools.c
index 993fb3c..ca40d4d 100644
--- a/src/tracefs-tools.c
+++ b/src/tracefs-tools.c
@@ -307,13 +307,13 @@ int tracefs_option_enable(struct tracefs_instance *instance, enum tracefs_option
 }
 
 /**
  * tracefs_option_diasble - Disable trace option
  * @instance: ftrace instance, can be NULL for the top instance
  * @id: trace option id
  *
  * Returns -1 in case of an error or 0 otherwise
  */
-int tracefs_option_diasble(struct tracefs_instance *instance, enum tracefs_option_id id)
+int tracefs_option_disable(struct tracefs_instance *instance, enum tracefs_option_id id)
 {
 	return trace_config_option(instance, id, false);
 }
@@ -307,13 +307,13 @@ int tracefs_option_enable(struct tracefs_instance *instance, enum tracefs_option
 
 /**
- * tracefs_option_diasble - Disable trace option
+ * tracefs_option_disable - Disable trace option
  * @instance: ftrace instance, can be NULL for the top instance
  * @id: trace option id
-- 
2.27.0


  parent reply	other threads:[~2021-06-08 13:55 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-06-08 13:55 [PATCH 1/4] libtracefs: Fix enable_disable_all() return value Yordan Karadzhov (VMware)
2021-06-08 13:55 ` [PATCH 2/4] libtracefs: Fix event_enable_disable() " Yordan Karadzhov (VMware)
2021-06-08 13:55 ` Yordan Karadzhov (VMware) [this message]
2021-06-08 13:55 ` [PATCH 4/4] libtracefs: Propagate the return value of the callback function Yordan Karadzhov (VMware)
2021-06-09 17:00   ` Steven Rostedt
2021-06-11 11:03     ` Yordan Karadzhov (VMware)

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210608135503.12135-3-y.karadz@gmail.com \
    --to=y.karadz@gmail.com \
    --cc=linux-trace-devel@vger.kernel.org \
    --cc=rostedt@goodmis.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.